#
# spec file for package drawing
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name com.github.maoschanz.drawing
Name:           drawing
Version:        1.0.2
Release:        1.4
Summary:        A simple drawing application for Linux
License:        GPL-3.0-only
Group:          Productivity/Graphics/Bitmap Editors
URL:            https://github.com/maoschanz/drawing
Source:         https://github.com/maoschanz/drawing/archive/refs/tags/%{version}.tar.gz
Source2:        drawing-rpmlintrc
BuildRequires:  fdupes
BuildRequires:  gobject-introspection
BuildRequires:  itstool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-gobject
BuildRequires:  python3-gobject-devel
BuildRequires:  python3-pycairo
BuildRequires:  pkgconfig(gtk+-3.0)
Requires:       python3
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-gobject-cairo
Requires:       python3-pycairo
Recommends:     yelp
BuildArch:      noarch

%description
This application is a free basic image editor, similar to Microsoft Paint, is aiming at the GNOME desktop.

PNG, JPEG and BMP files are supported.

Besides GNOME, the app is well integrated in traditional-looking desktops, as well as an elementaryOS layout.

It should also be compatible with the Pinephone and Librem 5 smartphones.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} --with-gnome
%fdupes -s %{buildroot}

%files
%license LICENSE
%doc CONTRIBUTING.md README.md
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{_name}.desktop
%{_datadir}/glib-2.0/schemas/%{_name}.gschema.xml
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/metainfo/%{_name}.appdata.xml

%files lang -f %{name}.lang

%changelog
* Wed Mar 29 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.2:
  * fix the default value of the text background option (as
    reported by #521 and #559)
  * fix a scenario where saving without transparency would
    consistently fail
  * automatically reload the picture after saving
  * mitigate initial state of the "filters" tool if "blur" is
    selected
  * change the keyboard shortcuts to switch tabs
  * remove from the highlighter the (ineffective) UI to change
    the active cairo operator
  * change the UI of the selection tools to improve readability
    of various items
  * fix typos in the user help manual
  * change the label of the "toggle the preview" menu item
  * update several translations
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 1.0.1:
  * enable the highlighter by default (#458)
  * less intrusive "what's new" message dialog (#504)
  * non-linear zooming speed profile (to zoom faster when using extreme values) (#499)
  * slower scrolling speed to have a better precision with higher zoom levels (#499)
  * require itstool as a dependency even though it's some useless bloat
  * fix the adaptivity of the elementaryOS layout (#502)
  * better keep the image centered on the mouse pointer when changing the zoom (#499)
  * avoid —again— insane attempts to open the binary as an image (#500)
  * update several translations
- drop meson_build.patch (upstream)
* Thu Apr  7 2022 Emily Gonyer <emilyyrose@gmail.com>
- Fixed translation and help file locations.
* Mon Apr  4 2022 Emily Gonyer <emilyyrose@gmail.com>
- Patched meson.build in help to fix build issue with itstool which kept it from building.
  meson_build.patch
* Sun Apr  3 2022 Emily Gonyer <emilyyrose@gmail.com>
- updated to 1.0.0 release
  - enable tools with "alt+letter" mnemonics
  - larger sidebar items, where the selected tool is easier to see
  - new "skew" tool
  - enable or disable specific tools options with the [shift] or [alt] keyboard modifiers
  - show more numerous, more dynamic, more contextual help tips as the window's subtitle
  - display cursor coordinates and other related data when pressing the [ctrl] keyboard modifier
  - dynamically change the label of the "options" submenu in the menu-bar, to increase its discoverability
  - scale tool option to set the size in percentage
  - suggest to "apply & save" when trying to save while an operation is unapplied
  - highlighter option to straighten the line, so it better follows the underlying text
  - improvements to the "points" tool's numbers readability
  - suggest to "apply & deselect" when trying to save while the    selection is active
  - more precise tools for tiny modifications required by pixel-art
  - display pixels sharply when zooming deeper than 400%%
  - hide information messages after 4 seconds if they're not that useful
  - disable the 'reload image from the disk' action if the image has never been saved
  - new 'reset the canvas' action (ctrl+backspace)
  - warn the user if they're opening an already opened image
  - suggest to reload the picture if it has changed on the disk
  - artificially limited framerate to avoid overloading the CPU
  - menu item and action to change the theme variant preference
  - toggle the menubar with ctrl+f2
  - update the user help manual
  - shorter appdata summary, to comply with guidelines
  - update several translations
* Wed Mar  2 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add explicit itstool BuildRequires, as meson.build checks for it:
  do not expect anything else to pull it in.
* Mon May  3 2021 Marcus Meissner <meissner@suse.com>
- use BuildRequires: gobject-introspection instead of hardrequiring
  typelibs, remove -lang recommends, handled better automatically.
* Sat May  1 2021 Marcus Meissner <meissner@suse.com>
- updated 0.8.0 release
  - new, richer, more readable bottom pane for the selection tool
  - add a "replace with" option to the eraser tool
  - use an adequate layout on LXDE or LXQt
  - force the release notes down users' throat (#347)
  - rewrite the help manual to better force it down users' throat (#347)
  - add color application mode support to the "shape" tool (#329)
  - persist the text background style (#340) and the shape filling style options
  - brush supporting pressure-sensitive input (#69, #116)
  - hairy brush supporting pressure-sensitive input (#69, #116)
  - airbrush supporting pressure-sensitive input (#69, #116)
  - calligraphic nip supporting pressure-sensitive input (#69, #116)
  - fix unexpected "jumps" when unselecting a selection that was defined by an undo
  - improve the fullscreen mode, with a way to toggle the tools list (#265, #189)
  - add an "increase constrast" filter (#308)
  - deleting the selection can now leave something else than transparency #232
  - option to exclude the color left under the selection from the selection itself #232
  - rewrite the UI for changing the color application mode (#329)
  - remove the cool but deprecated GNOME Shell app menu
  - improve flatpak CI (#319, Bilel Moussaoui)
  - update several translations
* Thu Feb 11 2021 slbtongying <shenlebantongying@gmail.com>
- initial upload.
